@@ -24,14 +24,14 @@ The views and conclusions contained in the software and documentation are those
 of the authors and should not be interpreted as representing official policies,
 either expressed or implied, of the Regents of The University of Michigan.
 */
+#include <errno.h>
 
+#define _GNU_SOURCE  // Possible fix for 16.04
 #define __USE_GNU
-#include <pthread.h>
-#include <sched.h>
+#include "common/pthreads_cross.h"
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <inttypes.h>
 #ifdef _WIN32
 #include <windows.h>
 #else
@@ -39,9 +39,7 @@ either expressed or implied, of the Regents of The University of Michigan.
 #endif
 
 #include "workerpool.h"
-#include "timeprofile.h"
-#include "math_util.h"
-#include "string_util.h"
+#include "debug_print.h"
 
 struct workerpool {
     int nthreads;
@@ -118,8 +116,9 @@ workerpool_t *workerpool_create(int nthreads)
         for (int i = 0; i < nthreads; i++) {
             int res = pthread_create(&wp->threads[i], NULL, worker_thread, wp);
             if (res != 0) {
-                perror("pthread_create");
-                exit(-1);
+                debug_print("Insufficient system resources to create workerpool threads\n");
+                // errno already set to EAGAIN by pthread_create() failure
+                return NULL;
             }
         }
     }
