@@ -33,6 +33,7 @@ either expressed or implied, of the Regents of The University of Michigan.
 #include <stdint.h>
 
 #include "zmaxheap.h"
+#include "debug_print.h"
 
 #ifdef _WIN32
 static inline long int random(void)
@@ -176,8 +177,7 @@ void zmaxheap_vmap(zmaxheap_t *heap, void (*f)())
         void *p = NULL;
         memcpy(&p, &heap->data[idx*heap->el_sz], heap->el_sz);
         if (p == NULL) {
-            printf("Warning: zmaxheap_vmap item %d is NULL\n", idx);
-            fflush(stdout);
+            debug_print("Warning: zmaxheap_vmap item %d is NULL\n", idx);
         }
         f(p);
     }
