@@ -26,6 +26,7 @@ either expressed or implied, of the Regents of The University of Michigan.
 */
 
 #include <iostream>
+#include <iomanip>
 
 #include "opencv2/opencv.hpp"
 
@@ -66,6 +67,11 @@ int main(int argc, char *argv[])
         exit(0);
     }
 
+    cout << "Enabling video capture" << endl;
+    
+    TickMeter meter;
+    meter.start();
+
     // Initialize camera
     VideoCapture cap(0);
     if (!cap.isOpened()) {
@@ -100,14 +106,36 @@ int main(int argc, char *argv[])
 
     apriltag_detector_t *td = apriltag_detector_create();
     apriltag_detector_add_family(td, tf);
+
+    if (errno == ENOMEM) {
+        printf("Unable to add family to detector due to insufficient memory to allocate the tag-family decoder with the default maximum hamming value of 2. Try choosing an alternative tag family.\n");
+        exit(-1);
+    }
+    
     td->quad_decimate = getopt_get_double(getopt, "decimate");
     td->quad_sigma = getopt_get_double(getopt, "blur");
     td->nthreads = getopt_get_int(getopt, "threads");
     td->debug = getopt_get_bool(getopt, "debug");
     td->refine_edges = getopt_get_bool(getopt, "refine-edges");
 
+    float frame_counter = 0.0f;
+    meter.stop();
+    cout << "Detector " << famname << " initialized in " 
+        << std::fixed << std::setprecision(3) << meter.getTimeSec() << " seconds" << endl;
+#if CV_MAJOR_VERSION > 3
+    cout << "  " << cap.get(CAP_PROP_FRAME_WIDTH ) << "x" <<
+                    cap.get(CAP_PROP_FRAME_HEIGHT ) << " @" <<
+                    cap.get(CAP_PROP_FPS) << "FPS" << endl;
+#else
+    cout << "  " << cap.get(CV_CAP_PROP_FRAME_WIDTH ) << "x" <<
+                    cap.get(CV_CAP_PROP_FRAME_HEIGHT ) << " @" <<
+                    cap.get(CV_CAP_PROP_FPS) << "FPS" << endl;
+#endif
+    meter.reset();
+
     Mat frame, gray;
     while (true) {
+        errno = 0;
         cap >> frame;
         cvtColor(frame, gray, COLOR_BGR2GRAY);
 
@@ -120,6 +148,11 @@ int main(int argc, char *argv[])
 
         zarray_t *detections = apriltag_detector_detect(td, &im);
 
+        if (errno == EAGAIN) {
+            printf("Unable to create the %d threads requested.\n",td->nthreads);
+            exit(-1);
+        }
+
         // Draw detection outlines
         for (int i = 0; i < zarray_size(detections); i++) {
             apriltag_detection_t *det;
